@@ -407,10 +407,10 @@ namespace eval editor {
 					-text [mc "Indentation mode"]		\
 					-helptext [mc "What to do when you press enter\n\tnone\t- start on the beginning of the next line\n\tnormal\t- keep indention of the previous line"]	\
 				] -row 2 -column 0 -sticky w -padx 5
-				grid [ttk::combobox $editing_labelframe.imode_cb			\
-					-values [list [mc "none"] [mc "normal"]]			\
-					-state readonly							\
-					-width 0							\
+				grid [ttk::combobox $editing_labelframe.imode_cb	\
+					-values [list "none" "normal"]			\
+					-state readonly					\
+					-width 0					\
 					-textvariable ::configDialogues::editor::intentation_mode	\
 				] -row 2 -column 1 -sticky we -padx 5
 				bind $editing_labelframe.imode_cb <<ComboboxSelected>>	\
@@ -1767,7 +1767,7 @@ namespace eval editor {
 		set highlight_tags_lst	${::LSTsyntaxHighlight::highlight_tags}
 
 		# Get data from editor NS
-		set intentation_mode		[mc ${::Editor::intentation_mode}]
+		set intentation_mode		${::Editor::intentation_mode}
 		set spaces_no_tabs		${::Editor::spaces_no_tabs}
 		set number_of_spaces		${::Editor::number_of_spaces}
 		set tab_width			${::Editor::tab_width}
@@ -1876,7 +1876,7 @@ namespace eval editor {
 		set FileList::default_eol	$default_eol
 
 		## Editor
-		set Editor::intentation_mode	[mc $intentation_mode]
+		set Editor::intentation_mode	$intentation_mode
 		set Editor::spaces_no_tabs	$spaces_no_tabs
 		set Editor::auto_brackets	$auto_brackets
 		set Editor::hg_trailing_sp	$hg_trailing_sp
