@@ -1,10 +1,13 @@
 #!/usr/bin/tclsh
-# Part of MCU 8051 IDE ( http://mcu8051ide.sf.net )
+# Part of MCU 8051 IDE ( http://http://www.moravia-microsystems.com/mcu8051ide )
 
 ############################################################################
 #    Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012 by Martin Ošmera     #
 #    martin.osmera@gmail.com                                               #
 #                                                                          #
+#    Copyright (C) 2014 by Moravia Microsystems, s.r.o.                    #
+#    martin.osmera@moravia-microsystems.com                                #
+#                                                                          #
 #    This program is free software; you can redistribute it and#or modify  #
 #    it under the terms of the GNU General Public License as published by  #
 #    the Free Software Foundation; either version 2 of the License, or     #
@@ -41,17 +44,17 @@ class LedPanel {
 	inherit VirtualHWComponent
 
 	# Font: Font to be used in the panel -- bold
-	common cb_font	[font create				\
+	public common cb_font	[font create				\
 		-weight bold					\
 		-size [expr {int(-10 * $::font_size_factor)}]	\
 		-family {helvetica}				\
 	]
-	common COMPONENT_NAME	"LED Panel"	;# Name of this component
-	common CLASS_NAME	"LedPanel"	;# Name of this class
-	common COMPONENT_ICON	{ledpanel}	;# Icon for this panel (16x16)
+	public common COMPONENT_NAME	"LED Panel"	;# Name of this component
+	public common CLASS_NAME	"LedPanel"	;# Name of this class
+	public common COMPONENT_ICON	{ledpanel}	;# Icon for this panel (16x16)
 
 	# Configuration menu
-	common CONFMENU {
+	public common CONFMENU {
 		{cascade	{Color}			0	"colorize"	.color	false 1 {
 			{radiobutton	"Red"		{}
 				::LedPanel::color		{red}
